@@ -125,7 +125,8 @@ int hci_le_create_conn(int dd, uint16_t interval, uint16_t window,
 		bdaddr_t peer_bdaddr, uint8_t own_bdaddr_type,
 		uint16_t min_interval, 	uint16_t max_interval,
 		uint16_t latency, uint16_t supervision_timeout,
-		uint16_t min_ce_length, uint16_t max_ce_length);
+		uint16_t min_ce_length, uint16_t max_ce_length,
+		uint16_t *handle, int to);
 
 int hci_for_each_dev(int flag, int(*func)(int dd, int dev_id, long arg), long arg);
 int hci_get_route(bdaddr_t *bdaddr);
